@@ -1,9 +1,10 @@
 # <@LICENSE>
-# Copyright 2004 Apache Software Foundation
-# 
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to you under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at:
 # 
 #     http://www.apache.org/licenses/LICENSE-2.0
 # 
@@ -269,6 +270,10 @@ sub parse {
   # reason, so convert them to spaces.  Confirmed in 3.31, at least.
   $text =~ s/&nbsp;/ /g;
 
+  # bug 4695: we want "<br/>" to be treated the same as "<br>", and
+  # the HTML::Parser API won't do it for us
+  $text =~ s/<(\w+)\s*\/>/<$1>/gi;
+
   # ALWAYS pack it into byte-representation, even if we're using 'use bytes',
   # since the HTML::Parser object may use Unicode internally. (bug 1417,
   # maybe).  Also, ignore stupid warning that can't be suppressed: 'Parsing of
@@ -652,9 +657,6 @@ sub html_tests {
   if ($tag eq "img" && exists $self->{inside}{a} && $self->{inside}{a} > 0) {
     $self->{uri}->{$self->{anchor_last}}->{anchor_text}->[-1] .= "<img>\n";
     $self->{anchor}->[-1] .= "<img>\n";
-    if ($self->{anchor_last} =~ /\.(?:pl|cgi|php|asp|jsp|cfm)\b/i) {
-      $self->put_results(anchor_image_bug => 1);
-    }
   }
 
   if ($tag eq "img" && exists $attr->{width} && exists $attr->{height}) {
@@ -678,12 +680,6 @@ sub html_tests {
       $area = $width * $height;
       $self->{image_area} += $area;
     }
-    # this is intended to match any width and height if they're specified
-    if (exists $attr->{src} &&
-	$attr->{src} =~ /\.(?:pl|cgi|php|asp|jsp|cfm)\b/i)
-    {
-      $self->put_results(web_bugs => 1);
-    }
   }
   if ($tag eq "form" && exists $attr->{action}) {
     $self->put_results(form_action_mailto => 1) if $attr->{action} =~ /mailto:/i
